import { defineStore } from "pinia";
import { useAPI } from "./api";
import { Budget, useSessionStore } from "./session";

interface State {
    CurrentBudgetID: string | null,
}

export const useBudgetsStore = defineStore('budget', {
    state: (): State => ({
        CurrentBudgetID: null  
    }),
    actions: {
        setCurrentBudgetID(budgetid : string) {
            this.CurrentBudgetID = budgetid;
        },
    },
    getters: {
        CurrentBudget() : Budget | undefined {
            if (this.CurrentBudgetID == null)
                return undefined;

            const sessionStore = useSessionStore();
            return sessionStore.Budgets.get(this.CurrentBudgetID);
        },
        CurrentBudgetName() : string {
            return this.CurrentBudget?.Name ?? "";
        },
        CurrentBudgetID() : string | undefined {
            return this.CurrentBudgetID;
        },
        ImportYNAB(formData) {
            const api = useAPI();
            return api.POST(
                "/budget/" + this.CurrentBudgetID + "/import/ynab", 
                formData
            );
        },
        async NewBudget(budgetName) {
            const api = useAPI();
            const result = await api.POST(
                "/budget/new",
                JSON.stringify({ name: budgetName })
            );
            const response = await result.json();

            const sessionStore = useSessionStore();
            sessionStore.Budgets.set(response.ID, response);
        },
        async SetCurrentBudget(budgetid : string) {
            this.CurrentBudgetID = budgetid;

            if (budgetid == null)
                return

            await dispatch(FETCH_BUDGET, budgetid)
        },
    }
})